==> o365-2.0.5.tar.gz: o365/src/AuthenticationServiceInterface.php <==
<?php

namespace Drupal\o365;

/**
 * The AuthenticationServiceInterface interface.
 */
interface AuthenticationServiceInterface {

  /**
   * Redirect the user to the correct Microsoft pages for oAuth2.
   *
   * @param \Drupal\o365\O365ConnectorInterface $o365_connector
   *   The Office 365 connector entity.
   */
  public function loginUser(O365ConnectorInterface $o365_connector);

  /**
   * Get the access token for the user.
   *
   * @param bool $login
   *   If we want to login the user if there is no token.
   *
   * @return string|bool
   *   The access token or FALSE.
   *
   * @throws \Drupal\Core\TempStore\TempStoreException
   * @throws \League\OAuth2\Client\Provider\Exception\IdentityProviderException
   */
  public function getAccessToken(bool $login = FALSE);

  /**
   * Generate and save the accessToken.
   *
   * @param string $code
   *   The code we got from Microsoft.
   * @param \Drupal\o365\O365ConnectorInterface $o365_connector
   *   The Office 365 connector entity.
   * @param mixed $redirect
   *   Either FALSE or a url where to redirect to.
   *
   * @throws \Drupal\Core\TempStore\TempStoreException
   * @throws \League\OAuth2\Client\Provider\Exception\IdentityProviderException
   */
  public function setAccessToken(string $code, O365ConnectorInterface $o365_connector, $redirect);

  /**
   * Save the auth data from the cookie in the user session storage.
   *
   * @throws \Drupal\Core\TempStore\TempStoreException
   */
  public function saveAuthDataFromCookie();

}

==> o365-3.0.1.tar.gz: o365/src/AuthenticationServiceInterface.php <==
<?php

namespace Drupal\o365;

/**
 * The interface for the AuthenticationService.
 */
interface AuthenticationServiceInterface {

  /**
   * Redirect the user to the correct Microsoft pages for oAuth2.
   */
  public function redirectToAuthorizationUrl();

  /**
   * Generate and save the accessToken.
   *
   * @param string $code
   *   The code we got from Microsoft.
   * @param mixed $redirect
   *   Either FALSE or a url where to redirect to.
   *
   * @throws \Drupal\Core\TempStore\TempStoreException
   * @throws \League\OAuth2\Client\Provider\Exception\IdentityProviderException
   */

  /**
   * Generate and save the accessToken.
   *
   * @param string $code
   *   The code we got from Microsoft.
   * @param bool|string $redirect
   *   Either FALSE or an url where to redirect to.
   *
   * @throws \Drupal\Core\TempStore\TempStoreException
   * @throws \League\OAuth2\Client\Provider\Exception\IdentityProviderException
   */
  public function setAccessToken($code, $redirect);

  /**
   * Get the access token for the user.
   *
   * @param bool $login
   *   If we want to login the user if there is no token.
   *
   * @return string
   *   The access token.
   *
   * @throws \Drupal\Core\TempStore\TempStoreException
   * @throws \League\OAuth2\Client\Provider\Exception\IdentityProviderException
   */
  public function getAccessToken($login = FALSE);

  /**
   * Save the auth data from the cookie in the user session storage.
   *
   * @throws \Drupal\Core\TempStore\TempStoreException
   */
  public function saveAuthDataFromCookie();

  /**
   * Save the auth data from the url parameters in the user session storage.
   *
   * @throws \Drupal\Core\TempStore\TempStoreException
   */
  public function saveAuthDataFromUrl();

  /**
   * Check if a user is logged in via Office.
   *
   * @return string|bool
   *   The users ID or FALSE if not logged in via Office.
   */
  public function checkForOfficeLogin();

}
